@@ -147,6 +147,56 @@ class DictMethodChemRefHelper(object):
                     wObj.setValue("RESID", "resource_name", iRow)
                     wObj.setValue(dbId, "resource_accession_code", iRow)
                     wObj.setValue("matching by RESID resource", "related_mapping_method", iRow)
+            # JDW JDW
+            # --- Add pubchem mapping ---
+            pubchemProvider = rP.getResource("PubChemProvider instance") if rP else None
+            pubchemMapD = pubchemProvider.getIdentifiers()
+            if pubchemMapD and ccId in pubchemMapD:
+                pharosProvider = rP.getResource("PharosProvider instance") if rP else None
+                pharosChemblD = pharosProvider.getIdentifiers()
+
+                if not dataContainer.exists(catName):
+                    dataContainer.append(DataCategory(catName, attributeNameList=self.__dApi.getAttributeNameList(catName)))
+                wObj = dataContainer.getObj(catName)
+                for rName in ["ChEBI", "ChEMBL", "CAS", "PubChem"]:
+                    rL = wObj.selectIndices(rName, "resource_name")
+                    if rL:
+                        ok = wObj.removeRows(rL)
+                        if not ok:
+                            logger.debug("Error removing rows in %r %r", catName, rL)
+                #
+                logger.debug("Using PubChem mapping length %d", len(pubchemMapD))
+                xD = {}
+                for rD in pubchemMapD[ccId]:
+                    for tName, tObj in rD.items():
+                        if tName == "pcId":
+                            xD.setdefault("PubChem", set()).add(tObj)
+                        elif tName in ["CAS", "ChEBI"]:
+                            for tId in tObj:
+                                xD.setdefault(tName, set()).add(tId)
+                        elif tName in ["ChEMBL"]:
+                            for tId in tObj:
+                                xD.setdefault(tName, set()).add(tId)
+                                if pharosChemblD and tId in pharosChemblD:
+                                    logger.info("Mapping ccId %r to Pharos %r", ccId, tId)
+                                    xD.setdefault("Pharos", set()).add(tId)
+
+                #
+                for rName, rIdS in xD.items():
+                    if rName in ["PubChem", "Pharos"]:
+                        aMethod = "matching InChIKey in PubChem"
+                    elif rName in ["CAS", "ChEMBL", "ChEBI"]:
+                        aMethod = "assigned by PubChem resource"
+                    elif rName in ["Pharos"]:
+                        aMethod = "matching ChEMBL ID in Pharos"
+                    for rId in rIdS:
+                        iRow = wObj.getRowCount()
+                        wObj.setValue(ccId, "comp_id", iRow)
+                        wObj.setValue(iRow + 1, "ordinal", iRow)
+                        wObj.setValue(rName, "resource_name", iRow)
+                        wObj.setValue(rId, "resource_accession_code", iRow)
+                        wObj.setValue(aMethod, "related_mapping_method", iRow)
+
             return True
         except Exception as e:
             logger.exception("For %s failing with %s", catName, str(e))
@@ -184,6 +234,7 @@ class DictMethodChemRefHelper(object):
                 dbMapD = dbD["id_map"]
                 inKeyD = dbD["inchikey_map"]
                 atcD = dbD["db_atc_map"]
+                logger.info("DrugBank correspondence length is %d", len(dbMapD))
                 logger.debug("atcD length is %d", len(atcD))
                 logger.debug("inKeyD length is %d", len(inKeyD))
                 #
